@@ -12,7 +12,6 @@
 
 #include <stdbool.h>
 #include <sys/sysinfo.h>
-#include <sys/utsname.h>
 #include <zconf.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -20,7 +19,7 @@
 #include <getopt.h>
 #include <ctype.h>
 #include <string.h>
-#include <signal.h>
+#include <strings.h>
 #include <syslog.h>
 #include <limits.h>
 #include <dirent.h>
@@ -29,28 +28,39 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
+#include <sys/queue.h>
+#include <fcntl.h>
+#include <signal.h>
 
-#include "Handle.h"
-#include "TriggerThreadProcs.h"
-#include "Process.h"
-#include "Logging.h"
-
-#define MAX_TRIGGERS 3
+#define MAX_TRIGGERS 10
 #define NO_PID INT_MAX
-#define MAX_CMDLINE_LEN 4096+1
-#define EMPTY_PROC_NAME "null"
-#define MIN_KERNEL_VERSION 3
-#define MIN_KERNEL_PATCH 5
+#define EMPTY_PROC_NAME "(null)"
 
 #define MIN_POLLING_INTERVAL 1000   // default trigger polling interval (ms)
+#define MAX_DUMP_COUNT 100          // maximum number of dumps that can be requested to be collected
 
 // -------------------
 // Structs
 // -------------------
 
+struct TriggerThread
+{
+    pthread_t thread;
+    enum TriggerType trigger;
+};
+
+struct MonitoredProcessMapEntry
+{
+    bool active;
+    long long starttime;
+};
+
 struct ProcDumpConfiguration {
     // Process and System info
     pid_t ProcessId;
+    pid_t ProcessGroup;         // -pgid
+    bool bProcessGroup;         // -pgid
+
     char *ProcessName;
     struct sysinfo SystemInfo;
 
@@ -58,10 +68,13 @@ struct ProcDumpConfiguration {
     int NumberOfDumpsCollecting; // Number of dumps we're collecting
     int NumberOfDumpsCollected; // Number of dumps we have collected
     bool bTerminated; // Do we know whether the process has terminated and subsequently whether we are terminating?
+    char* socketPath;
+    bool bExitProcessMonitor;
 
     // Quit
     int nQuit; // if not 0, then quit
     struct Handle evtQuit; // for signalling threads we are quitting
+    int statusSocket;   // Socket used to wait for target process reporting status to procdump
 
 
     // Trigger behavior
@@ -70,27 +83,38 @@ struct ProcDumpConfiguration {
     bool bTriggerThenSnoozeTimer;   // Detect+Trigger=>Wait N second=>[repeat]
 
     // Options
-    int CpuThreshold;               // -C
-    bool bCpuTriggerBelowValue;     // -c
-    int MemoryThreshold;            // -M
-    bool bMemoryTriggerBelowValue;  // -m
+    int CpuThreshold;               // -c
+    bool bCpuTriggerBelowValue;     // -cl
+    int* MemoryThreshold;           // -m
+    int MemoryThresholdCount;
+    int MemoryCurrentThreshold;
+    bool bMemoryTriggerBelowValue;  // -m or -ml
+    bool bMonitoringGCMemory;       // -gcm
+    int DumpGCGeneration;           // -gcgen
     int ThresholdSeconds;           // -s
     bool bTimerThreshold;           // -s
     int NumberOfDumpsToCollect;     // -n
     bool WaitingForProcessName;     // -w
-    bool DiagnosticsLoggingEnabled; // -d
-    int ThreadThreshold;            // -T
-    int FileDescriptorThreshold;    // -F
-    int SignalNumber;               // -G    
-    int PollingInterval;            // -I
-    char *CoreDumpPath;             // -o
-    char *CoreDumpName;             // -o
+    bool DiagnosticsLoggingEnabled; // -log
+    int ThreadThreshold;            // -tc
+    int FileDescriptorThreshold;    // -fc
+    int SignalNumber;               // -sig
+    int PollingInterval;            // -pf
+    char *CoreDumpPath;             //
+    char *CoreDumpName;             //
+    bool bOverwriteExisting;        // -o
+    bool bDumpOnException;          // -e
+    char *ExceptionFilter;          // -f
 
     // multithreading
     // set max number of concurrent dumps on init (default to 1)
     int nThreads;
-    pthread_t Threads[MAX_TRIGGERS];
-    struct Handle semAvailableDumpSlots; 
+    struct TriggerThread Threads[MAX_TRIGGERS];
+    struct Handle semAvailableDumpSlots;
+    pthread_mutex_t ptrace_mutex;
+    pthread_cond_t dotnetCond;
+    pthread_mutex_t dotnetMutex;
+    bool bSocketInitialized;
 
     // Events
     // use these to mimic WaitForSingleObject/MultibleObjects from WinApi
@@ -104,29 +128,22 @@ struct ProcDumpConfiguration {
     pid_t gcorePid;
 };
 
-int GetOptions(struct ProcDumpConfiguration *self, int argc, char *argv[]);
-char * GetProcessName(pid_t pid);
-bool LookupProcessByPid(struct ProcDumpConfiguration *self);
-bool WaitForProcessName(struct ProcDumpConfiguration *self);
-int CreateProcessViaDebugThreadAndWaitUntilLaunched(struct ProcDumpConfiguration *self);
-int CreateTriggerThreads(struct ProcDumpConfiguration *self);
-int WaitForQuit(struct ProcDumpConfiguration *self, int milliseconds);
-int WaitForQuitOrEvent(struct ProcDumpConfiguration *self, struct Handle *handle, int milliseconds);
-int WaitForAllThreadsToTerminate(struct ProcDumpConfiguration *self);
-bool IsQuit(struct ProcDumpConfiguration *self);
-int SetQuit(struct ProcDumpConfiguration *self, int quit);
-bool PrintConfiguration(struct ProcDumpConfiguration *self);
-bool ContinueMonitoring(struct ProcDumpConfiguration *self);
-bool BeginMonitoring(struct ProcDumpConfiguration *self);
+struct ConfigQueueEntry {
+    struct ProcDumpConfiguration * config;
 
+    TAILQ_ENTRY(ConfigQueueEntry) element;
+};
+
+int GetOptions(struct ProcDumpConfiguration *self, int argc, char *argv[]);
+bool PrintConfiguration(struct ProcDumpConfiguration *self);
+void ApplyDefaults(struct ProcDumpConfiguration *self);  // Call this after GetOptions has been called to set default values
 void FreeProcDumpConfiguration(struct ProcDumpConfiguration *self);
+struct ProcDumpConfiguration * CopyProcDumpConfiguration(struct ProcDumpConfiguration *self);
 void InitProcDumpConfiguration(struct ProcDumpConfiguration *self);
 void InitProcDump();
 void ExitProcDump();
-
 void PrintBanner();
-int PrintUsage(struct ProcDumpConfiguration *self);
-bool IsValidNumberArg(const char *arg);
-bool CheckKernelVersion();
+int PrintUsage();
+
 
 #endif // PROCDUMPCONFIGURATION_H
